summaryrefslogtreecommitdiff
path: root/src/script/api/script_news.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/script/api/script_news.cpp')
-rw-r--r--src/script/api/script_news.cpp14
1 files changed, 12 insertions, 2 deletions
diff --git a/src/script/api/script_news.cpp b/src/script/api/script_news.cpp
index 8d808ff3c..5f84f96d6 100644
--- a/src/script/api/script_news.cpp
+++ b/src/script/api/script_news.cpp
@@ -11,13 +11,17 @@
#include "../../stdafx.h"
#include "script_news.hpp"
+#include "script_industry.hpp"
+#include "script_station.hpp"
+#include "script_map.hpp"
+#include "script_town.hpp"
#include "script_error.hpp"
#include "../../command_type.h"
#include "../../string_func.h"
#include "../../safeguards.h"
/* static */ bool ScriptNews::Create(NewsType type, Text *text, ScriptCompany::CompanyID company)
{
CCountedPtr<Text> counter(text);
@@ -26,9 +30,15 @@
EnforcePreconditionEncodedText(false, encoded);
EnforcePrecondition(false, type == NT_ECONOMY || type == NT_SUBSIDIES || type == NT_GENERAL);
EnforcePrecondition(false, company == ScriptCompany::COMPANY_INVALID || ScriptCompany::ResolveCompanyID(company) != ScriptCompany::COMPANY_INVALID);
+ EnforcePrecondition(false, (ref_type == NR_NONE) ||
+ (ref_type == NR_TILE && ScriptMap::IsValidTile(reference)) ||
+ (ref_type == NR_STATION && ScriptStation::IsValidStation(reference)) ||
+ (ref_type == NR_INDUSTRY && ScriptIndustry::IsValidIndustry(reference)) ||
+ (ref_type == NR_TOWN && ScriptTown::IsValidTown(reference)));
uint8 c = company;
if (company == ScriptCompany::COMPANY_INVALID) c = INVALID_COMPANY;
- return ScriptObject::DoCommand(0, type | (NR_NONE << 8) | (c << 16), 0, CMD_CUSTOM_NEWS_ITEM, encoded);
+ if (ref_type == NR_NONE) reference = 0;
+ return ScriptObject::DoCommand(0, type | (ref_type << 8) | (c << 16), reference, CMD_CUSTOM_NEWS_ITEM, encoded);
}
@@ -11,13 +11,17 @@
#include "../../string_func.h"
#include "../../safeguards.h"
-/* static */ bool ScriptNews::Create(NewsType type, Text *text, ScriptCompany::CompanyID company)
+/* static */ bool ScriptNews::Create(NewsType type, Text *text, ScriptCompany::CompanyID company, NewsReferenceType ref_type, uint32 reference)
{
CCountedPtr<Text> counter(text);